@@ -18,33 +18,20 @@
  *
  *  Authors:
  *    Lauris Kaplinski <lauris@helixcode.com>
- *    Chema Celorio <chema@celorio.com>
- *
- *  Copyright 2001 Ximian, Inc.
+ *    Chema Celorio <chema@ximian.com>
  *
+ *  Copyright 2001-2003 Ximian, Inc.
  */
 
 #include <config.h>
-
 #include <ctype.h>
 #include <stdlib.h>
 #include <locale.h>
 
-#include "gpa/gpa-node-private.h"
-#include "gnome-print-config.h"
-
-/*
- * I changed GnomePrintConfig form being a boxed type to a GObject, because app developers are going
- * to g_object_unref anyways and when it crashes they are just going to not unref it at all. Move the
- * following macros to the .h file and make gnome_print_config_[un]ref a macro rather
- * than a function call for GNOME 2.4 (Chema)
- */
-#define GNOME_TYPE_PRINT_CONFIG         (gnome_print_config_get_type ())
-#define GNOME_PRINT_CONFIG(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GNOME_TYPE_PRINT_CONFIG, GnomePrintConfig))
-#define GNOME_PRINT_CONFIG_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), GNOME_TYPE_PRINT_CONFIG, GnomePrintConfigClass))
-#define GNOME_IS_PRINT_CONFIG(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNOME_TYPE_PRINT_CONFIG))
-#define GNOME_IS_PRINT_CONFIG_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), GNOME_TYPE_PRINT_CONFIG))
-#define GNOME_PRINT_CONFIG_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GNOME_TYPE_PRINT_CONFIG, GnomePrintConfigClass))
+#include <libgnomeprint/gpa/gpa-config.h>
+#include <libgnomeprint/gnome-print-config.h>
+#include <libgnomeprint/gnome-print-config-private.h>
+#include <libgnomeprint/gnome-print-job.h>
 
 typedef struct _GnomePrintConfigClass GnomePrintConfigClass;
 
@@ -127,7 +114,7 @@ gnome_print_config_default (void)
 	GnomePrintConfig *config;
 
 	config = g_object_new (GNOME_TYPE_PRINT_CONFIG, NULL);
-	config->node = gpa_defaults ();
+	config->node = (GPANode *) gpa_config_new ();
 
 	return config;
 }
@@ -303,7 +290,8 @@ gnome_print_config_get_length (GnomePrintConfig *config, const guchar *key, gdou
 			g_free (v);
 			return FALSE;
 		}
-		while (*e && !isalnum (*e)) e++;
+		while (*e && !isalnum (*e))
+			e++;
 		if (!*e) {
 			c_unit = GNOME_PRINT_PS_UNIT;
 		} else {
@@ -394,10 +382,65 @@ gnome_print_config_set_length (GnomePrintConfig *config, const guchar *key, gdou
 }
 
 
+gchar *
+gnome_print_config_to_string (GnomePrintConfig *config, guint flags)
+{
+	g_return_val_if_fail (config != NULL, NULL);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONFIG (config), NULL);
+
+	return gpa_config_to_string (GPA_CONFIG (config->node), flags);
+}
+
+GnomePrintConfig *
+gnome_print_config_from_string (const gchar *str,
+				guint flags)
+{
+	GnomePrintConfig *config;
+
+	g_return_val_if_fail (str != NULL, NULL);
+
+	config = g_object_new (GNOME_TYPE_PRINT_CONFIG, NULL);
+	config->node = (GPANode *) gpa_config_from_string (str, flags);
+
+	return config;
+}
+
 void
 gnome_print_config_dump (GnomePrintConfig *config)
 {
 	g_return_if_fail (config != NULL);
+	g_return_if_fail (GNOME_IS_PRINT_CONFIG (config));
 
-	gpa_utils_dump_tree (config->node, 2);
+	gpa_utils_dump_tree (config->node, 1);
+}
+
+/**
+ * gnome_print_config_get_page_size
+ * @config: 
+ * @width: 
+ * @height: 
+ * 
+ * Get imaging area size available to the application for printing
+ * after margins and layouts are applied. Sizes are given in PS
+ * points (GNOME_PRINT_PS_UNIT)
+ * 
+ * Return Value: TRUE on success, FALSE on error
+ **/
+gboolean
+gnome_print_config_get_page_size (GnomePrintConfig *config, gdouble *width, gdouble *height)
+{
+	GnomePrintJob *job;
+
+	g_return_val_if_fail (config != NULL, FALSE);
+	g_return_val_if_fail (GNOME_IS_PRINT_CONFIG (config), FALSE);
+	g_return_val_if_fail (width != NULL, FALSE);
+	g_return_val_if_fail (height != NULL, FALSE);
+
+	job = gnome_print_job_new (config);
+
+	gnome_print_job_get_page_size (job, width, height);
+
+	g_object_unref (G_OBJECT (job));
+
+	return TRUE;
 }
