@@ -722,17 +722,22 @@ job_parse_config_data (GnomePrintJob *job)
 				gint pagenum;
 				affines = g_new (gdouble, 6 * numlp);
 				pagenum = 0;
-				for (page = gpa_node_get_child (pages, NULL); page != NULL; page = gpa_node_get_child (pages, page)) {
+
+				while (pagenum < numlp) {
 					guchar *transform;
+					guchar *child_id;
+					child_id = g_strdup_printf ("LP%d", pagenum);
+					page = gpa_node_get_child_from_path (pages, child_id);
 					transform = gpa_node_get_value (page);
 					gpa_node_unref (page);
-					if (!transform)
+					if (!transform) {
+						g_warning ("Could not fetch transfrom from %s\n", child_id);
 						break;
+					}
 					job_parse_transform (transform, affines + 6 * pagenum);
 					g_free (transform);
+					g_free (child_id);
 					pagenum += 1;
-					if (pagenum >= numlp)
-						break;
 				}
 				gpa_node_unref (pages);
 				if (pagenum == numlp) {
