@@ -385,9 +385,9 @@ gnome_print_pdf_clip (GnomePrintContext *ctx, const ArtBpath *bpath, ArtWindRule
 	gnome_print_pdf_print_bpath (pdf, bpath);
 
 	if (rule == ART_WIND_RULE_NONZERO) {
-		gnome_print_pdf_page_fprintf (pdf, "W" EOL);
+		gnome_print_pdf_page_fprintf (pdf, "W n" EOL);
 	} else {
-		gnome_print_pdf_page_fprintf (pdf, "W*" EOL);
+		gnome_print_pdf_page_fprintf (pdf, "W* n" EOL);
 	}
 
 	return GNOME_PRINT_OK;
