@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  gnome-print-transport.c: abstract base class for transport providers
+ *  gnome-print-transport.c: Abstract base class for transport providers
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -19,25 +19,22 @@
  *  Authors:
  *    Raph Levien <raph@acm.org>
  *    Miguel de Icaza <miguel@kernel.org>
- *    Lauris Kaplinski <lauris@ximian.com>
+ *    Lauris Kaplinski <lauris@helixcode.com>
  *    Chema Celorio <chema@celorio.com>
  *
- *  Copyright (C) 1999-2001 Ximian, Inc. and authors
- *
+ *  Copyright 2000-2003 Ximian, Inc. and authors
  */
 
-#define __GNOME_PRINT_TRANSPORT_C__
-
-#include "config.h"
+#include <config.h>
 #include <string.h>
 #include <locale.h>
+
 #include <gmodule.h>
-#include "gnome-print.h"
-#include "gnome-print-transport.h"
+#include <libgnomeprint/gnome-print.h>
+#include <libgnomeprint/gnome-print-transport.h>
 
 static void gnome_print_transport_class_init (GnomePrintTransportClass *klass);
 static void gnome_print_transport_init (GnomePrintTransport *transport);
-
 static void gnome_print_transport_finalize (GObject *object);
 
 static GnomePrintTransport *gnome_print_transport_create (gpointer get_type, GnomePrintConfig *config);
@@ -109,7 +106,6 @@ gnome_print_transport_construct (GnomePrintTransport *transport, GnomePrintConfi
 	g_return_val_if_fail (transport != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (GNOME_IS_PRINT_TRANSPORT (transport), GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (config != NULL, GNOME_PRINT_ERROR_UNKNOWN);
-
 	g_return_val_if_fail (transport->config == NULL, GNOME_PRINT_ERROR_UNKNOWN);
 
 	transport->config = gnome_print_config_ref (config);
@@ -307,8 +303,11 @@ gnome_print_transport_create (gpointer get_type, GnomePrintConfig *config)
 	transport = g_object_new (type, NULL);
 	retval = gnome_print_transport_construct (transport, config);
 
-	if (retval != GNOME_PRINT_OK)
+	if (retval != GNOME_PRINT_OK) {
+		g_warning ("Error while constructing transport inside transport_create");
+		g_object_unref (G_OBJECT (transport));
 		return NULL;
+	}
 
 	return transport;
 }
