@@ -284,9 +284,6 @@ gpa_node_set_value (GPANode *node, const guchar *value)
 void
 gpa_node_emit_modified (GPANode *node)
 {
-#if 0	
-	g_print ("Emit modified for %s\n", gpa_node_id (node));
-#endif
 	g_signal_emit (G_OBJECT (node), node_signals [MODIFIED], 0, 0);
 }
 
@@ -349,10 +346,8 @@ gpa_node_get_path_value (GPANode *node, const guchar *path)
  * @path: 
  * @value: 
  * 
- * It might return TRUE even when the value can't be set, for example
- * if you are setting List.DefaultChild  and DefaultChild doesn't exist we can't
- * know offhand if is valid because it is done with a signal emission
- * 
+ * Set the value of the child pointed by @path starting from @parent
+ *
  * Return Value: 
  **/
 gboolean
